@@ -544,3 +544,59 @@ get_observed_synergies_per_cell_line = function(cell.line.dirs, drug.combos) {
 
   return(res)
 }
+
+#' Get synergy scores from file
+#'
+#' Use this function to read \href{https://druglogics.github.io/druglogics-doc/drabme-install.html#drabme-output}{Drabme's
+#' output files} that have synergy scores for a list of tested drug perturbations.
+#'
+#' Two types of files can be read: the \emph{model-wise} and the \emph{ensemble-wise}
+#' synergies:
+#' \itemize{
+#'   \item The \emph{model-wise} synergies data is structured as a 3-column
+#' table, first being the names of the tested drug combinations, second the
+#' number of models that predicted that combination as synergistic and the third
+#' the number of models that predicted the drug combination as non-synergistic.
+#'   \item The \emph{ensemble-wise} synergies data is structured as a 2-column table,
+#' the first being the names of drug combinations and the second the ensemble-wise
+#' synergy scores for those perturbations.
+#'  }
+#'
+#' Note that no matter the file type, the first line of the file is always skipped
+#' and the columns must be \emph{tab-separated}.
+#' See example below for the format of such files generated by the
+#' \href{https://druglogics.github.io/druglogics-doc/drabme.html}{Drabme} module.
+#'
+#' @param file_name string. The name of the file, can be a full path.
+#' @param file_type string. The type of input file, can be either \emph{ensemblewise}
+#' (default option) or \emph{modelwise}.
+#'
+#' @return a \code{tibble} containing a representation of the data in the file.
+#'
+#' @examples
+#'
+#' ensemblewise_synergies_file = system.file("extdata", "ensemblewise_synergies",
+#'   package = "emba", mustWork = TRUE)
+#' modelwise_synergies_file = system.file("extdata", "modelwise_synergies",
+#'   package = "emba", mustWork = TRUE)
+#' data_ensemble = get_synergy_scores(ensemblewise_synergies_file) # file_type = "ensemblewise"
+#' data_modelwise = get_synergy_scores(modelwise_synergies_file, file_type = "modelwise")
+#'
+#' @importFrom readr read_tsv
+#' @export
+get_synergy_scores = function(file_name, file_type = "ensemblewise") {
+  stopifnot(file.exists(file_name))
+  type = match.arg(arg = file_type, choices = c("ensemblewise", "modelwise"))
+
+  if (type == "ensemblewise") {
+    res = read_tsv(file = file_name, skip = 1, col_types = "cd",
+      col_names = c('perturbation', 'score'))
+  } else { # model-wise
+    res = read_tsv(file = file_name, skip = 1, col_types = "cii",
+      col_names = c('perturbation', 'synergies', 'non-synergies'))
+  }
+
+  res$perturbation = gsub('\\[|\\]', '', res$perturbation)
+
+  return(res)
+}
